(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{59:function(e,t,a){e.exports=a(68)},68:function(e,t,a){"use strict";a.r(t);var r=a(5),n=a.n(r),l=a(49),o=a.n(l),s=a(0),i=a(1),c=a(2),m=a(3),d=a(46),p=a(87),u=a(88),g=a(85),f=a(89),h=a(17),b=a(54);h.d.register(h.c,h.i,h.k,h.h,h.o,h.p,h.f);var x=function(e){var t=e.dataRows;if(e instanceof Array)return e;for(var a=[],r=1;r<=t;r++)a.push(e.getCell(r,1).content);return a},E={responsive:!0,plugins:{legend:{display:!1}},scales:{x:{grid:{drawBorder:!1}},y:{grid:{display:!1,drawBorder:!1}}}},y=function(e){return null!==e?n.a.createElement(p.a,{sx:{fontWeight:"bold"}},"S = ",e):n.a.createElement(p.a,{sx:{fontWeight:"bold"}},"S = \xd8")},C=function(e,t,a,r,n,l,o){var s=[];e[0]instanceof Date?s=e.map((function(e){return new Date(1e6*e.getTime())})).map((function(e){return e.toLocaleString()})):s=e;return null==n?{labels:s,datasets:[{label:a,data:t,borderColor:r,backgroundColor:r,tension:.5,pointRadius:2}]}:{labels:s,datasets:[{label:"Seuil",data:t.map((function(e){return n})),borderColor:l,backgroundColor:l,borderWidth:2,pointRadius:0,pointHitRadius:0},{label:a,data:t,borderColor:r,backgroundColor:r,tension:.5,pointRadius:2}]}},w=function(e){Object(c.a)(a,e);var t=Object(m.a)(a);function a(){var e;Object(i.a)(this,a);for(var r=arguments.length,l=new Array(r),o=0;o<r;o++)l[o]=arguments[o];return(e=t.call.apply(t,[this].concat(l))).state={},e.title=e.props.args.title,e.x=x(e.props.args.x),e.y=x(e.props.args.y),e.labels=e.props.args.labels,e.metrics=e.props.args.metrics,e.defaultColor=e.props.args.defaultColor,e.threshColor=e.props.args.threshColor,e.thresh=e.props.args.thresh,e.format=e.props.args.format,e.data=C(e.x,e.y,e.title,e.defaultColor,e.thresh,e.threshColor,e.format),e.render=function(){return n.a.createElement(u.a,{sx:{padding:2}},n.a.createElement(g.a,{sx:{height:250,width:290}},n.a.createElement(f.a,null,n.a.createElement(u.a,null,n.a.createElement(u.a,{sx:{display:"flex",justifyContent:"space-between",alignItems:"center"}},n.a.createElement(p.a,{sx:{fontWeight:"bold"}},e.title),y(e.thresh),n.a.createElement(p.a,{sx:{fontWeight:"bold"}},e.labels.y)),n.a.createElement(u.a,{sx:{marginTop:2,display:"flex",justifyContent:"space-between",alignItems:"center"}},n.a.createElement(u.a,{sx:{display:"flex",alignItems:"center"}},n.a.createElement(p.a,{sx:{marginLeft:1,fontWeight:"bold"}},"min"),n.a.createElement(p.a,null,"=",e.metrics.min)),n.a.createElement(u.a,{sx:{display:"flex",alignItems:"center"}},n.a.createElement(p.a,{sx:{marginLeft:1,fontWeight:"bold"}},"x\u0304"),n.a.createElement(p.a,null,"=",e.metrics.mean)),n.a.createElement(u.a,{sx:{display:"flex",alignItems:"center"}},n.a.createElement(p.a,{sx:{marginLeft:1,fontWeight:"bold"}},"max"),n.a.createElement(p.a,null,"=",e.metrics.max))),n.a.createElement(u.a,{sx:{marginTop:2}},n.a.createElement(b.a,{options:E,data:e.data}))))))},e}return Object(s.a)(a)}(d.a),v=Object(d.b)(w);o.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(v,null)),document.getElementById("root"))}},[[59,1,2]]]);
//# sourceMappingURL=main.371af992.chunk.js.map